# CODATA

This package contains all the CODATA constants, uncertainties and units [1].
An update function is included in the package to update the CODATA constants whenever desired.

## How to use
The CODATA constants objects work just the same as floats. 
They only have some extra attributes, namely 'uncertainty', 'unit' and 'description', see the code below.
You can also acces a dictionary containing all the constants named 'constants'.
All the names of the constants are given in the next section Constant Names.

    >>> from CODATA import h, hbar, Wien
    >>> from math import pi
    
    >>> h
    6.62607004(81) e-34 [ J s ] Planck constant
    
    >>> hbar
    1.0545718(13) e-34 [ J s ] Planck constant over 2 pi
    
    >>> h.uncertainty
    8.1e-42
    
    >>> h.unit
    'J s'
    
    >>> abs(h / (2 * pi) - hbar) <= 1e-40
    True    

    >>> Wien.value
    0.0028977729

    >>> Wien.description
    'Wien wavelength displacement law constant'
    
    >>> import CODATA
    
    >>> CODATA.constants['speed of light in vacuum']
    299792458.0 [ m s^-1 ] speed of light in vacuum
    
    >>> CODATA.c
    299792458.0 [ m s^-1 ] speed of light in vacuum
    
    >>> CODATA.pico * CODATA.mega == CODATA.micro
    True 
    
    >>> CODATA.update()
    >>> CODATA.last_update
    time.struct_time(tm_year=2018, tm_mon=10, tm_mday=13, tm_hour=14, tm_min=15, tm_
    sec=6, tm_wday=5, tm_yday=286, tm_isdst=1)

## Constant Names
### Shortcut Constants 
First of all, shortcuts Variable Names to the most used constants have been made, listed down below.
Keys for the dictionary are used in the dictionary called 'constants', see the Examples above.

|Dictionary key           |Variable Names                                  |Value                     |
|-------------------------|-----------------------------------------------|--------------------------|
|speed of light in vacuum|c, c0, speed_of_light|299792458.0 m s^-1|
|Planck constant|h, planck_constant|6.62607004e-34 J s|
|Planck constant over 2 pi|hbar, Planck_constant_over_2_pi|1.0545718e-34 J s|
|elementary charge|e, elementary_charge|1.6021766208e-19 C|
|electron mass|m_e, electron_mass|9.10938356e-31 kg|
|proton mass|m_p, proton_mass|1.672621898e-27 kg|
|neutron mass|m_n, neutron_mass|1.674927471e-27 kg|
|mag. constant|mu_0, mag_constant, magnetic_constant|1.2566370614e-06 N A^-2|
|electric constant|epsilon_0, electric_constant|8.854187817e-12 F m^-1|
|Boltzmann constant|k, Boltzmann_constant|1.38064852e-23 J K^-1 |
|Stefan Boltzman constant|sigma, Stefan_Boltzmann_constant|5.670367e-08 W m^-2 K^-4|
|molar gas constant|R, universal_gas_constant, ideal_gas_constant, gas_constant|8.3144598 J mol^-1 K^-1|
|Newtonian constant of gravitation|G, Newtonian_constant_of_gravitation, gravitation_constant, universal_gravitation_constant|6.67408e-11 m^3 kg^-1 s^-2|
|Rydberg constant|Rydberg, Rydberg_constant|10973731.568508 m^-1|
|Wien wavelength displacement law constant|Wien, Wien_constant, Wien_wavelength_displacement_law_constant|0.0028977729 m K|
|Avogadro constant|N_A, L, Avogadro_number, Avogadro|6.022140857e23 mol^-1|
|electron volt|eV, electron_volt|1.6021766208e-19 J|

### All Constants
All the CODATA dictionary keys and corrosponding variable names are listed below. 
Again the keys for the dictionary are used in the dictionary called 'constants', see the Examples above.

|Dictionary key           |Variable Name                                  |Value
|-------------------------|-----------------------------------------------|--------------------------|
|{220} lattice spacing of silicon|_220_lattice_spacing_of_silicon|1.920155714e-10 m|
|alpha particle-electron mass ratio|alpha_particle_electron_mass_ratio|7294.29954136 -|
|alpha particle mass|alpha_particle_mass|6.64465723e-27 kg|
|alpha particle mass energy equivalent|alpha_particle_mass_energy_equivalent|5.971920097e-10 J|
|alpha particle mass energy equivalent in MeV|alpha_particle_mass_energy_equivalent_in_MeV|3727.379378 MeV|
|alpha particle mass in u|alpha_particle_mass_in_u|4.001506179127 u|
|alpha particle molar mass|alpha_particle_molar_mass|0.004001506179127 kg mol^-1|
|alpha particle-proton mass ratio|alpha_particle_proton_mass_ratio|3.97259968907 -|
|Angstrom star|Angstrom_star|1.00001495e-10 m|
|atomic mass constant|atomic_mass_constant|1.66053904e-27 kg|
|atomic mass constant energy equivalent|atomic_mass_constant_energy_equivalent|1.492418062e-10 J|
|atomic mass constant energy equivalent in MeV|atomic_mass_constant_energy_equivalent_in_MeV|931.4940954 MeV|
|atomic mass unit-electron volt relationship|atomic_mass_unit_electron_volt_relationship|931494095.4 eV|
|atomic mass unit-hartree relationship|atomic_mass_unit_hartree_relationship|34231776.902 E_h|
|atomic mass unit-hertz relationship|atomic_mass_unit_hertz_relationship|2.2523427206e+23 Hz|
|atomic mass unit-inverse meter relationship|atomic_mass_unit_inverse_meter_relationship|751300661660000.0 m^-1|
|atomic mass unit-joule relationship|atomic_mass_unit_joule_relationship|1.492418062e-10 J|
|atomic mass unit-kelvin relationship|atomic_mass_unit_kelvin_relationship|10809543800000.0 K|
|atomic mass unit-kilogram relationship|atomic_mass_unit_kilogram_relationship|1.66053904e-27 kg|
|atomic unit of 1st hyperpolarizability|atomic_unit_of_1st_hyperpolarizability|3.206361329e-53 C^3 m^3 J^-2|
|atomic unit of 2nd hyperpolarizability|atomic_unit_of_2nd_hyperpolarizability|6.235380085e-65 C^4 m^4 J^-3|
|atomic unit of action|atomic_unit_of_action|1.0545718e-34 J s|
|atomic unit of charge|atomic_unit_of_charge|1.6021766208e-19 C|
|atomic unit of charge density|atomic_unit_of_charge_density|1081202377000.0 C m^-3|
|atomic unit of current|atomic_unit_of_current|0.006623618183 A|
|atomic unit of electric dipole mom.|atomic_unit_of_electric_dipole_mom|8.478353552e-30 C m|
|atomic unit of electric field|atomic_unit_of_electric_field|514220670700.0 V m^-1|
|atomic unit of electric field gradient|atomic_unit_of_electric_field_gradient|9.717362356e+21 V m^-2|
|atomic unit of electric polarizability|atomic_unit_of_electric_polarizability|1.6487772731e-41 C^2 m^2 J^-1|
|atomic unit of electric potential|atomic_unit_of_electric_potential|27.21138602 V|
|atomic unit of electric quadrupole mom.|atomic_unit_of_electric_quadrupole_mom|4.486551484e-40 C m^2|
|atomic unit of energy|atomic_unit_of_energy|4.35974465e-18 J|
|atomic unit of force|atomic_unit_of_force|8.23872336e-08 N|
|atomic unit of length|atomic_unit_of_length|5.2917721067e-11 m|
|atomic unit of mag. dipole mom.|atomic_unit_of_mag_dipole_mom|1.854801999e-23 J T^-1|
|atomic unit of mag. flux density|atomic_unit_of_mag_flux_density|235051.755 T|
|atomic unit of magnetizability|atomic_unit_of_magnetizability|7.8910365886e-29 J T^-2|
|atomic unit of mass|atomic_unit_of_mass|9.10938356e-31 kg|
|atomic unit of mom.um|atomic_unit_of_momum|1.992851882e-24 kg m s^-1|
|atomic unit of permittivity|atomic_unit_of_permittivity|1.112650056e-10 F m^-1|
|atomic unit of time|atomic_unit_of_time|2.418884326509e-17 s|
|atomic unit of velocity|atomic_unit_of_velocity|2187691.26277 m s^-1|
|Avogadro constant|Avogadro_constant|6.022140857e+23 mol^-1|
|Bohr magneton|Bohr_magneton|9.274009994e-24 J T^-1|
|Bohr magneton in eV/T|Bohr_magneton_in_eVT|5.7883818012e-05 eV T^-1|
|Bohr magneton in Hz/T|Bohr_magneton_in_HzT|13996245042.0 Hz T^-1|
|Bohr magneton in inverse meters per tesla|Bohr_magneton_in_inverse_meters_per_tesla|46.68644814 m^-1 T^-1|
|Bohr magneton in K/T|Bohr_magneton_in_KT|0.67171405 K T^-1|
|Bohr radius|Bohr_radius|5.2917721067e-11 m|
|Boltzmann constant|Boltzmann_constant|1.38064852e-23 J K^-1|
|Boltzmann constant in eV/K|Boltzmann_constant_in_eVK|8.6173303e-05 eV K^-1|
|Boltzmann constant in Hz/K|Boltzmann_constant_in_HzK|20836612000.0 Hz K^-1|
|Boltzmann constant in inverse meters per kelvin|Boltzmann_constant_in_inverse_meters_per_kelvin|69.503457 m^-1 K^-1|
|characteristic impedance of vacuum|characteristic_impedance_of_vacuum|376.730313461 ohm|
|classical electron radius|classical_electron_radius|2.8179403227e-15 m|
|Compton wavelength|Compton_wavelength|2.4263102367e-12 m|
|Compton wavelength over 2 pi|Compton_wavelength_over_2_pi|3.8615926764e-13 m|
|conductance quantum|conductance_quantum|7.748091731e-05 S|
|conventional value of Josephson constant|conventional_value_of_Josephson_constant|483597900000000.0 Hz V^-1|
|conventional value of von Klitzing constant|conventional_value_of_von_Klitzing_constant|25812.807 ohm|
|Cu x unit|Cu_x_unit|1.00207697e-13 m|
|deuteron-electron mag. mom. ratio|deuteron_electron_mag_mom_ratio|-0.0004664345535 -|
|deuteron-electron mass ratio|deuteron_electron_mass_ratio|3670.48296785 -|
|deuteron g factor|deuteron_g_factor|0.8574382311 -|
|deuteron mag. mom.|deuteron_mag_mom|4.33073504e-27 J T^-1|
|deuteron mag. mom. to Bohr magneton ratio|deuteron_mag_mom_to_Bohr_magneton_ratio|0.0004669754554 -|
|deuteron mag. mom. to nuclear magneton ratio|deuteron_mag_mom_to_nuclear_magneton_ratio|0.8574382311 -|
|deuteron mass|deuteron_mass|3.343583719e-27 kg|
|deuteron mass energy equivalent|deuteron_mass_energy_equivalent|3.005063183e-10 J|
|deuteron mass energy equivalent in MeV|deuteron_mass_energy_equivalent_in_MeV|1875.612928 MeV|
|deuteron mass in u|deuteron_mass_in_u|2.013553212745 u|
|deuteron molar mass|deuteron_molar_mass|0.002013553212745 kg mol^-1|
|deuteron-neutron mag. mom. ratio|deuteron_neutron_mag_mom_ratio|-0.44820652 -|
|deuteron-proton mag. mom. ratio|deuteron_proton_mag_mom_ratio|0.3070122077 -|
|deuteron-proton mass ratio|deuteron_proton_mass_ratio|1.99900750087 -|
|deuteron rms charge radius|deuteron_rms_charge_radius|2.1413e-15 m|
|electric constant|electric_constant|8.854187817e-12 F m^-1|
|electron charge to mass quotient|electron_charge_to_mass_quotient|-175882002400.0 C kg^-1|
|electron-deuteron mag. mom. ratio|electron_deuteron_mag_mom_ratio|-2143.923499 -|
|electron-deuteron mass ratio|electron_deuteron_mass_ratio|0.0002724437107484 -|
|electron g factor|electron_g_factor|-2.00231930436182 -|
|electron gyromag. ratio|electron_gyromag_ratio|176085964400.0 s^-1 T^-1|
|electron gyromag. ratio over 2 pi|electron_gyromag_ratio_over_2_pi|28024.95164 MHz T^-1|
|electron-helion mass ratio|electron_helion_mass_ratio|0.0001819543074854 -|
|electron mag. mom.|electron_mag_mom|-9.28476462e-24 J T^-1|
|electron mag. mom. anomaly|electron_mag_mom_anomaly|0.00115965218091 -|
|electron mag. mom. to Bohr magneton ratio|electron_mag_mom_to_Bohr_magneton_ratio|-1.00115965218091 -|
|electron mag. mom. to nuclear magneton ratio|electron_mag_mom_to_nuclear_magneton_ratio|-1838.28197234 -|
|electron mass|electron_mass|9.10938356e-31 kg|
|electron mass energy equivalent|electron_mass_energy_equivalent|8.18710565e-14 J|
|electron mass energy equivalent in MeV|electron_mass_energy_equivalent_in_MeV|0.5109989461 MeV|
|electron mass in u|electron_mass_in_u|0.00054857990907 u|
|electron molar mass|electron_molar_mass|5.4857990907e-07 kg mol^-1|
|electron-muon mag. mom. ratio|electron_muon_mag_mom_ratio|206.766988 -|
|electron-muon mass ratio|electron_muon_mass_ratio|0.0048363317 -|
|electron-neutron mag. mom. ratio|electron_neutron_mag_mom_ratio|960.9205 -|
|electron-neutron mass ratio|electron_neutron_mass_ratio|0.00054386734428 -|
|electron-proton mag. mom. ratio|electron_proton_mag_mom_ratio|-658.2106866 -|
|electron-proton mass ratio|electron_proton_mass_ratio|0.000544617021352 -|
|electron-tau mass ratio|electron_tau_mass_ratio|0.000287592 -|
|electron to alpha particle mass ratio|electron_to_alpha_particle_mass_ratio|0.0001370933554798 -|
|electron to shielded helion mag. mom. ratio|electron_to_shielded_helion_mag_mom_ratio|864.058257 -|
|electron to shielded proton mag. mom. ratio|electron_to_shielded_proton_mag_mom_ratio|-658.2275971 -|
|electron-triton mass ratio|electron_triton_mass_ratio|0.0001819200062203 -|
|electron volt|electron_volt|1.6021766208e-19 J|
|electron volt-atomic mass unit relationship|electron_volt_atomic_mass_unit_relationship|1.0735441105e-09 u|
|electron volt-hartree relationship|electron_volt_hartree_relationship|0.03674932248 E_h|
|electron volt-hertz relationship|electron_volt_hertz_relationship|241798926200000.0 Hz|
|electron volt-inverse meter relationship|electron_volt_inverse_meter_relationship|806554.4005 m^-1|
|electron volt-joule relationship|electron_volt_joule_relationship|1.6021766208e-19 J|
|electron volt-kelvin relationship|electron_volt_kelvin_relationship|11604.5221 K|
|electron volt-kilogram relationship|electron_volt_kilogram_relationship|1.782661907e-36 kg|
|elementary charge|elementary_charge|1.6021766208e-19 C|
|elementary charge over h|elementary_charge_over_h|241798926200000.0 A J^-1|
|Faraday constant|Faraday_constant|96485.33289 C mol^-1|
|Faraday constant for conventional electric current|Faraday_constant_for_conventional_electric_current|96485.3251 C_90 mol^-1|
|Fermi coupling constant|Fermi_coupling_constant|1.1663787e-05 GeV^-2|
|fine-structure constant|fine_structure_constant|0.0072973525664 -|
|first radiation constant|first_radiation_constant|3.74177179e-16 W m^2|
|first radiation constant for spectral radiance|first_radiation_constant_for_spectral_radiance|1.191042953e-16 W m^2 sr^-1|
|hartree-atomic mass unit relationship|hartree_atomic_mass_unit_relationship|2.9212623197e-08 u|
|hartree-electron volt relationship|hartree_electron_volt_relationship|27.21138602 eV|
|Hartree energy|Hartree_energy|4.35974465e-18 J|
|Hartree energy in eV|Hartree_energy_in_eV|27.21138602 eV|
|hartree-hertz relationship|hartree_hertz_relationship|6579683920711000.0 Hz|
|hartree-inverse meter relationship|hartree_inverse_meter_relationship|21947463.13702 m^-1|
|hartree-joule relationship|hartree_joule_relationship|4.35974465e-18 J|
|hartree-kelvin relationship|hartree_kelvin_relationship|315775.13 K|
|hartree-kilogram relationship|hartree_kilogram_relationship|4.850870129e-35 kg|
|helion-electron mass ratio|helion_electron_mass_ratio|5495.88527922 -|
|helion g factor|helion_g_factor|-4.255250616 -|
|helion mag. mom.|helion_mag_mom|-1.074617522e-26 J T^-1|
|helion mag. mom. to Bohr magneton ratio|helion_mag_mom_to_Bohr_magneton_ratio|-0.001158740958 -|
|helion mag. mom. to nuclear magneton ratio|helion_mag_mom_to_nuclear_magneton_ratio|-2.127625308 -|
|helion mass|helion_mass|5.0064127e-27 kg|
|helion mass energy equivalent|helion_mass_energy_equivalent|4.499539341e-10 J|
|helion mass energy equivalent in MeV|helion_mass_energy_equivalent_in_MeV|2808.391586 MeV|
|helion mass in u|helion_mass_in_u|3.01493224673 u|
|helion molar mass|helion_molar_mass|0.00301493224673 kg mol^-1|
|helion-proton mass ratio|helion_proton_mass_ratio|2.99315267046 -|
|hertz-atomic mass unit relationship|hertz_atomic_mass_unit_relationship|4.4398216616e-24 u|
|hertz-electron volt relationship|hertz_electron_volt_relationship|4.135667662e-15 eV|
|hertz-hartree relationship|hertz_hartree_relationship|1.5198298460088e-16 E_h|
|hertz-inverse meter relationship|hertz_inverse_meter_relationship|3.335640951e-09 m^-1|
|hertz-joule relationship|hertz_joule_relationship|6.62607004e-34 J|
|hertz-kelvin relationship|hertz_kelvin_relationship|4.7992447e-11 K|
|hertz-kilogram relationship|hertz_kilogram_relationship|7.372497201e-51 kg|
|inverse fine-structure constant|inverse_fine_structure_constant|137.035999139 -|
|inverse meter-atomic mass unit relationship|inverse_meter_atomic_mass_unit_relationship|1.331025049e-15 u|
|inverse meter-electron volt relationship|inverse_meter_electron_volt_relationship|1.2398419739e-06 eV|
|inverse meter-hartree relationship|inverse_meter_hartree_relationship|4.556335252767e-08 E_h|
|inverse meter-hertz relationship|inverse_meter_hertz_relationship|299792458.0 Hz|
|inverse meter-joule relationship|inverse_meter_joule_relationship|1.986445824e-25 J|
|inverse meter-kelvin relationship|inverse_meter_kelvin_relationship|0.0143877736 K|
|inverse meter-kilogram relationship|inverse_meter_kilogram_relationship|2.210219057e-42 kg|
|inverse of conductance quantum|inverse_of_conductance_quantum|12906.4037278 ohm|
|Josephson constant|Josephson_constant|483597852500000.0 Hz V^-1|
|joule-atomic mass unit relationship|joule_atomic_mass_unit_relationship|6700535363.0 u|
|joule-electron volt relationship|joule_electron_volt_relationship|6.241509126e+18 eV|
|joule-hartree relationship|joule_hartree_relationship|2.293712317e+17 E_h|
|joule-hertz relationship|joule_hertz_relationship|1.509190205e+33 Hz|
|joule-inverse meter relationship|joule_inverse_meter_relationship|5.034116651e+24 m^-1|
|joule-kelvin relationship|joule_kelvin_relationship|7.2429731e+22 K|
|joule-kilogram relationship|joule_kilogram_relationship|1.112650056e-17 kg|
|kelvin-atomic mass unit relationship|kelvin_atomic_mass_unit_relationship|9.2510842e-14 u|
|kelvin-electron volt relationship|kelvin_electron_volt_relationship|8.6173303e-05 eV|
|kelvin-hartree relationship|kelvin_hartree_relationship|3.1668105e-06 E_h|
|kelvin-hertz relationship|kelvin_hertz_relationship|20836612000.0 Hz|
|kelvin-inverse meter relationship|kelvin_inverse_meter_relationship|69.503457 m^-1|
|kelvin-joule relationship|kelvin_joule_relationship|1.38064852e-23 J|
|kelvin-kilogram relationship|kelvin_kilogram_relationship|1.53617865e-40 kg|
|kilogram-atomic mass unit relationship|kilogram_atomic_mass_unit_relationship|6.022140857e+26 u|
|kilogram-electron volt relationship|kilogram_electron_volt_relationship|5.60958865e+35 eV|
|kilogram-hartree relationship|kilogram_hartree_relationship|2.061485823e+34 E_h|
|kilogram-hertz relationship|kilogram_hertz_relationship|1.356392512e+50 Hz|
|kilogram-inverse meter relationship|kilogram_inverse_meter_relationship|4.524438411e+41 m^-1|
|kilogram-joule relationship|kilogram_joule_relationship|8.987551787e+16 J|
|kilogram-kelvin relationship|kilogram_kelvin_relationship|6.5096595e+39 K|
|lattice parameter of silicon|lattice_parameter_of_silicon|5.431020504e-10 m|
|Loschmidt constant (273.15 K, 100 kPa)|Loschmidt_constant_27315_K_100_kPa|2.6516467e+25 m^-3|
|Loschmidt constant (273.15 K, 101.325 kPa)|Loschmidt_constant_27315_K_101325_kPa|2.6867811e+25 m^-3|
|mag. constant|mag_constant|1.2566370614e-06 N A^-2|
|mag. flux quantum|mag_flux_quantum|2.067833831e-15 Wb|
|molar gas constant|molar_gas_constant|8.3144598 J mol^-1 K^-1|
|molar mass constant|molar_mass_constant|0.001 kg mol^-1|
|molar mass of carbon-12|molar_mass_of_carbon_12|0.012 kg mol^-1|
|molar Planck constant|molar_Planck_constant|3.990312711e-10 J s mol^-1|
|molar Planck constant times c|molar_Planck_constant_times_c|0.119626565582 J m mol^-1|
|molar volume of ideal gas (273.15 K, 100 kPa)|molar_volume_of_ideal_gas_27315_K_100_kPa|0.022710947 m^3 mol^-1|
|molar volume of ideal gas (273.15 K, 101.325 kPa)|molar_volume_of_ideal_gas_27315_K_101325_kPa|0.022413962 m^3 mol^-1|
|molar volume of silicon|molar_volume_of_silicon|1.205883214e-05 m^3 mol^-1|
|Mo x unit|Mo_x_unit|1.00209952e-13 m|
|muon Compton wavelength|muon_Compton_wavelength|1.173444111e-14 m|
|muon Compton wavelength over 2 pi|muon_Compton_wavelength_over_2_pi|1.867594308e-15 m|
|muon-electron mass ratio|muon_electron_mass_ratio|206.7682826 -|
|muon g factor|muon_g_factor|-2.0023318418 -|
|muon mag. mom.|muon_mag_mom|-4.49044826e-26 J T^-1|
|muon mag. mom. anomaly|muon_mag_mom_anomaly|0.00116592089 -|
|muon mag. mom. to Bohr magneton ratio|muon_mag_mom_to_Bohr_magneton_ratio|-0.00484197048 -|
|muon mag. mom. to nuclear magneton ratio|muon_mag_mom_to_nuclear_magneton_ratio|-8.89059705 -|
|muon mass|muon_mass|1.883531594e-28 kg|
|muon mass energy equivalent|muon_mass_energy_equivalent|1.692833774e-11 J|
|muon mass energy equivalent in MeV|muon_mass_energy_equivalent_in_MeV|105.6583745 MeV|
|muon mass in u|muon_mass_in_u|0.1134289257 u|
|muon molar mass|muon_molar_mass|0.0001134289257 kg mol^-1|
|muon-neutron mass ratio|muon_neutron_mass_ratio|0.1124545167 -|
|muon-proton mag. mom. ratio|muon_proton_mag_mom_ratio|-3.183345142 -|
|muon-proton mass ratio|muon_proton_mass_ratio|0.1126095262 -|
|muon-tau mass ratio|muon_tau_mass_ratio|0.0594649 -|
|natural unit of action|natural_unit_of_action|1.0545718e-34 J s|
|natural unit of action in eV s|natural_unit_of_action_in_eV_s|6.582119514e-16 eV s|
|natural unit of energy|natural_unit_of_energy|8.18710565e-14 J|
|natural unit of energy in MeV|natural_unit_of_energy_in_MeV|0.5109989461 MeV|
|natural unit of length|natural_unit_of_length|3.8615926764e-13 m|
|natural unit of mass|natural_unit_of_mass|9.10938356e-31 kg|
|natural unit of mom.um|natural_unit_of_momum|2.730924488e-22 kg m s^-1|
|natural unit of mom.um in MeV/c|natural_unit_of_momum_in_MeVc|0.5109989461 MeV/c|
|natural unit of time|natural_unit_of_time|1.28808866712e-21 s|
|natural unit of velocity|natural_unit_of_velocity|299792458.0 m s^-1|
|neutron Compton wavelength|neutron_Compton_wavelength|1.31959090481e-15 m|
|neutron Compton wavelength over 2 pi|neutron_Compton_wavelength_over_2_pi|2.1001941536e-16 m|
|neutron-electron mag. mom. ratio|neutron_electron_mag_mom_ratio|0.00104066882 -|
|neutron-electron mass ratio|neutron_electron_mass_ratio|1838.68366158 -|
|neutron g factor|neutron_g_factor|-3.82608545 -|
|neutron gyromag. ratio|neutron_gyromag_ratio|183247172.0 s^-1 T^-1|
|neutron gyromag. ratio over 2 pi|neutron_gyromag_ratio_over_2_pi|29.1646933 MHz T^-1|
|neutron mag. mom.|neutron_mag_mom|-9.662365e-27 J T^-1|
|neutron mag. mom. to Bohr magneton ratio|neutron_mag_mom_to_Bohr_magneton_ratio|-0.00104187563 -|
|neutron mag. mom. to nuclear magneton ratio|neutron_mag_mom_to_nuclear_magneton_ratio|-1.91304273 -|
|neutron mass|neutron_mass|1.674927471e-27 kg|
|neutron mass energy equivalent|neutron_mass_energy_equivalent|1.505349739e-10 J|
|neutron mass energy equivalent in MeV|neutron_mass_energy_equivalent_in_MeV|939.5654133 MeV|
|neutron mass in u|neutron_mass_in_u|1.00866491588 u|
|neutron molar mass|neutron_molar_mass|0.00100866491588 kg mol^-1|
|neutron-muon mass ratio|neutron_muon_mass_ratio|8.89248408 -|
|neutron-proton mag. mom. ratio|neutron_proton_mag_mom_ratio|-0.68497934 -|
|neutron-proton mass difference|neutron_proton_mass_difference|2.30557377e-30 -|
|neutron-proton mass difference energy equivalent|neutron_proton_mass_difference_energy_equivalent|2.07214637e-13 -|
|neutron-proton mass difference energy equivalent in MeV|neutron_proton_mass_difference_energy_equivalent_in_MeV|1.29333205 -|
|neutron-proton mass difference in u|neutron_proton_mass_difference_in_u|0.001388449 -|
|neutron-proton mass ratio|neutron_proton_mass_ratio|1.00137841898 -|
|neutron-tau mass ratio|neutron_tau_mass_ratio|0.52879 -|
|neutron to shielded proton mag. mom. ratio|neutron_to_shielded_proton_mag_mom_ratio|-0.68499694 -|
|Newtonian constant of gravitation|Newtonian_constant_of_gravitation|6.67408e-11 m^3 kg^-1 s^-2|
|Newtonian constant of gravitation over h-bar c|Newtonian_constant_of_gravitation_over_h_bar_c|6.70861e-39 (GeV/c^2)^-2|
|nuclear magneton|nuclear_magneton|5.050783699e-27 J T^-1|
|nuclear magneton in eV/T|nuclear_magneton_in_eVT|3.152451255e-08 eV T^-1|
|nuclear magneton in inverse meters per tesla|nuclear_magneton_in_inverse_meters_per_tesla|0.02542623432 m^-1 T^-1|
|nuclear magneton in K/T|nuclear_magneton_in_KT|0.0003658269 K T^-1|
|nuclear magneton in MHz/T|nuclear_magneton_in_MHzT|7.622593285 MHz T^-1|
|Planck constant|Planck_constant|6.62607004e-34 J s|
|Planck constant in eV s|Planck_constant_in_eV_s|4.135667662e-15 eV s|
|Planck constant over 2 pi|Planck_constant_over_2_pi|1.0545718e-34 J s|
|Planck constant over 2 pi in eV s|Planck_constant_over_2_pi_in_eV_s|6.582119514e-16 eV s|
|Planck constant over 2 pi times c in MeV fm|Planck_constant_over_2_pi_times_c_in_MeV_fm|197.3269788 MeV fm|
|Planck length|Planck_length|1.616229e-35 m|
|Planck mass|Planck_mass|2.17647e-08 kg|
|Planck mass energy equivalent in GeV|Planck_mass_energy_equivalent_in_GeV|1.22091e+19 GeV|
|Planck temperature|Planck_temperature|1.416808e+32 K|
|Planck time|Planck_time|5.39116e-44 s|
|proton charge to mass quotient|proton_charge_to_mass_quotient|95788332.26 C kg^-1|
|proton Compton wavelength|proton_Compton_wavelength|1.32140985396e-15 m|
|proton Compton wavelength over 2 pi|proton_Compton_wavelength_over_2_pi|2.10308910109e-16 m|
|proton-electron mass ratio|proton_electron_mass_ratio|1836.15267389 -|
|proton g factor|proton_g_factor|5.585694702 -|
|proton gyromag. ratio|proton_gyromag_ratio|267522190.0 s^-1 T^-1|
|proton gyromag. ratio over 2 pi|proton_gyromag_ratio_over_2_pi|42.57747892 MHz T^-1|
|proton mag. mom.|proton_mag_mom|1.4106067873e-26 J T^-1|
|proton mag. mom. to Bohr magneton ratio|proton_mag_mom_to_Bohr_magneton_ratio|0.0015210322053 -|
|proton mag. mom. to nuclear magneton ratio|proton_mag_mom_to_nuclear_magneton_ratio|2.7928473508 -|
|proton mag. shielding correction|proton_mag_shielding_correction|2.5691e-05 -|
|proton mass|proton_mass|1.672621898e-27 kg|
|proton mass energy equivalent|proton_mass_energy_equivalent|1.503277593e-10 J|
|proton mass energy equivalent in MeV|proton_mass_energy_equivalent_in_MeV|938.2720813 MeV|
|proton mass in u|proton_mass_in_u|1.007276466879 u|
|proton molar mass|proton_molar_mass|0.001007276466879 kg mol^-1|
|proton-muon mass ratio|proton_muon_mass_ratio|8.88024338 -|
|proton-neutron mag. mom. ratio|proton_neutron_mag_mom_ratio|-1.45989805 -|
|proton-neutron mass ratio|proton_neutron_mass_ratio|0.99862347844 -|
|proton rms charge radius|proton_rms_charge_radius|8.751e-16 m|
|proton-tau mass ratio|proton_tau_mass_ratio|0.528063 -|
|quantum of circulation|quantum_of_circulation|0.00036369475486 m^2 s^-1|
|quantum of circulation times 2|quantum_of_circulation_times_2|0.00072738950972 m^2 s^-1|
|Rydberg constant|Rydberg_constant|10973731.568508 m^-1|
|Rydberg constant times c in Hz|Rydberg_constant_times_c_in_Hz|3289841960355000.0 Hz|
|Rydberg constant times hc in eV|Rydberg_constant_times_hc_in_eV|13.605693009 eV|
|Rydberg constant times hc in J|Rydberg_constant_times_hc_in_J|2.179872325e-18 J|
|Sackur-Tetrode constant (1 K, 100 kPa)|Sackur_Tetrode_constant_1_K_100_kPa|-1.1517084 -|
|Sackur-Tetrode constant (1 K, 101.325 kPa)|Sackur_Tetrode_constant_1_K_101325_kPa|-1.1648714 -|
|second radiation constant|second_radiation_constant|0.0143877736 m K|
|shielded helion gyromag. ratio|shielded_helion_gyromag_ratio|203789458.5 s^-1 T^-1|
|shielded helion gyromag. ratio over 2 pi|shielded_helion_gyromag_ratio_over_2_pi|32.43409966 MHz T^-1|
|shielded helion mag. mom.|shielded_helion_mag_mom|-1.07455308e-26 J T^-1|
|shielded helion mag. mom. to Bohr magneton ratio|shielded_helion_mag_mom_to_Bohr_magneton_ratio|-0.001158671471 -|
|shielded helion mag. mom. to nuclear magneton ratio|shielded_helion_mag_mom_to_nuclear_magneton_ratio|-2.12749772 -|
|shielded helion to proton mag. mom. ratio|shielded_helion_to_proton_mag_mom_ratio|-0.7617665603 -|
|shielded helion to shielded proton mag. mom. ratio|shielded_helion_to_shielded_proton_mag_mom_ratio|-0.7617861313 -|
|shielded proton gyromag. ratio|shielded_proton_gyromag_ratio|267515317.1 s^-1 T^-1|
|shielded proton gyromag. ratio over 2 pi|shielded_proton_gyromag_ratio_over_2_pi|42.57638507 MHz T^-1|
|shielded proton mag. mom.|shielded_proton_mag_mom|1.410570547e-26 J T^-1|
|shielded proton mag. mom. to Bohr magneton ratio|shielded_proton_mag_mom_to_Bohr_magneton_ratio|0.001520993128 -|
|shielded proton mag. mom. to nuclear magneton ratio|shielded_proton_mag_mom_to_nuclear_magneton_ratio|2.7927756 -|
|speed of light in vacuum|speed_of_light_in_vacuum|299792458.0 m s^-1|
|standard acceleration of gravity|standard_acceleration_of_gravity|9.80665 m s^-2|
|standard atmosphere|standard_atmosphere|101325.0 Pa|
|standard-state pressure|standard_state_pressure|100000.0 Pa|
|Stefan-Boltzmann constant|Stefan_Boltzmann_constant|5.670367e-08 W m^-2 K^-4|
|tau Compton wavelength|tau_Compton_wavelength|6.97787e-16 m|
|tau Compton wavelength over 2 pi|tau_Compton_wavelength_over_2_pi|1.11056e-16 m|
|tau-electron mass ratio|tau_electron_mass_ratio|3477.15 -|
|tau mass|tau_mass|3.16747e-27 kg|
|tau mass energy equivalent|tau_mass_energy_equivalent|2.84678e-10 J|
|tau mass energy equivalent in MeV|tau_mass_energy_equivalent_in_MeV|1776.82 MeV|
|tau mass in u|tau_mass_in_u|1.90749 u|
|tau molar mass|tau_molar_mass|0.00190749 kg mol^-1|
|tau-muon mass ratio|tau_muon_mass_ratio|16.8167 -|
|tau-neutron mass ratio|tau_neutron_mass_ratio|1.89111 -|
|tau-proton mass ratio|tau_proton_mass_ratio|1.89372 -|
|Thomson cross section|Thomson_cross_section|6.6524587158e-29 m^2|
|triton-electron mass ratio|triton_electron_mass_ratio|5496.92153588 -|
|triton g factor|triton_g_factor|5.95792492 -|
|triton mag. mom.|triton_mag_mom|1.504609503e-26 J T^-1|
|triton mag. mom. to Bohr magneton ratio|triton_mag_mom_to_Bohr_magneton_ratio|0.0016223936616 -|
|triton mag. mom. to nuclear magneton ratio|triton_mag_mom_to_nuclear_magneton_ratio|2.97896246 -|
|triton mass|triton_mass|5.007356665e-27 kg|
|triton mass energy equivalent|triton_mass_energy_equivalent|4.500387735e-10 J|
|triton mass energy equivalent in MeV|triton_mass_energy_equivalent_in_MeV|2808.921112 MeV|
|triton mass in u|triton_mass_in_u|3.01550071632 u|
|triton molar mass|triton_molar_mass|0.00301550071632 kg mol^-1|
|triton-proton mass ratio|triton_proton_mass_ratio|2.99371703348 -|
|unified atomic mass unit|unified_atomic_mass_unit|1.66053904e-27 kg|
|von Klitzing constant|von_Klitzing_constant|25812.8074555 ohm|
|weak mixing angle|weak_mixing_angle|0.2223 -|
|Wien frequency displacement law constant|Wien_frequency_displacement_law_constant|58789238000.0 Hz K^-1|
|Wien wavelength displacement law constant|Wien_wavelength_displacement_law_constant|0.0028977729 m K|

### SI - Prefixes
|Variable Name|Magnitude|
|-------------|---------|
|yotta|10<sup>24</sup>|
|zetta|10<sup>21</sup>|
|exa|10<sup>18</sup>|
|peta|10<sup>15</sup>|
|tera|10<sup>12</sup>|
|giga|10<sup>9</sup>|
|mega|10<sup>6</sup>|
|kilo|10<sup>3</sup>|
|hecto|10<sup>2</sup>|
|deka|10<sup>1</sup>|
|deci|10<sup>-1</sup>|
|centi|10<sup>-2</sup>|
|milli|10<sup>-3</sup>|
|micro|10<sup>-6</sup>|
|nano|10<sup>-9</sup>|
|pico|10<sup>-12</sup>|
|femto|10<sup>-15</sup>|
|atto|10<sup>-18</sup>|
|zepto|10<sup>-21</sup>|

## References

[1] : CODATA Recommended Values of the Fundamental Physical Constants.
      http://physics.nist.gov/cuu/Constants/index.html
